NonLinearSystemError

Enum NonLinearSystemError 

#[non_exhaustive]
pub enum NonLinearSystemError { NotFound(Id), WrongNumberGuesses { labels: usize, guesses: usize, }, MissingGuess { constraint_id: usize, variable: Id, }, FaerMatrix { error: CreationError, }, Faer { error: FaerError, }, FaerSolve { error: LuError, }, FaerSvd(SvdError), DidNotConverge, EmptySystemNotAllowed, }
Errors that could occur when running the core Newton-Gauss solve.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFound(Id)

ID was not found.



WrongNumberGuesses

There should be exactly 1 guess per variable, but you supplied the wrong number.

Fields

labels: usize

How many variables/labels were given.

guesses: usize

How many guesses were given.



MissingGuess

Constraint references a variable that doesn’t appear in the initial guesses.

Fields

constraint_id: usize

Which constraint ID referenced a missing variable.

variable: Id

Which variable was missing.



FaerMatrix

Faer: could not create a matrix.

Fields

error: CreationError

Underlying error.



Faer

Faer: general error.

Fields

error: FaerError

Underlying error.



FaerSolve

Faer: could not solve the matrix in the Newton-Gauss loop.

Fields

error: LuError

Underlying error.



FaerSvd(SvdError)

Faer: could not decompose Jacobian.



DidNotConverge

Solver did not find a solution within the allowed number of iterations. Consider raising the iterations?



EmptySystemNotAllowed

You provided an empty constraint system.